# Changelog

All notable changes to this project will be documented in this file.

## [0.4.0] - 2025-02-09

### 🚀 Features
- Introduce rules option in CacheMiddleware (#11)
- Add X-Cache header to indicate cache status (#14)
- Add cache invalidation functionality (#13)

### 📚 Documentation
- Add changelog and reference pages to docs
- fix incomplete docstring in invalidate_cache_for method
- small update to docs and signatures

### 🔩 Typing
- Add TypedDict for cache control directives (#19)

### 🚜 Refactor
- Add more ruff rules and fix them
- Simplify send handling in middleware via partial methods (#15)
- simplify decorators using a factory function (#18)

### 🧪 Testing
- Update test cases to use starlette TestClient (#17)

### ⚙️ Miscellaneous Tasks
- remove setup.cfg
- remove style tag from docs/changelog.md
- update branch name to main
- rename package to starlette-caches
- Add script to bump version and update changelog

<!-- generated by git-cliff -->

## Older releases

Older changes can be found in the original project's [changelog](https://github.com/florimondmanca/asgi-caches/blob/master/CHANGELOG.md).
